Package: rcompendium
Type: Package
Title: Create a Package or Research Compendium Structure
Version: 1.4
Authors@R: c(
    person(given   = "Nicolas",
           family  = "Casajus",
           role    = c("aut", "cre", "cph"),
           email   = "nicolas.casajus@fondationbiodiversite.fr",
           comment = c(ORCID = "0000-0002-5537-5294")))
Description: Makes easier the creation of R package or research compendium 
    (i.e. a predefined files/folders structure) so that users can focus on the 
    code/analysis instead of wasting time organizing files. A full 
    ready-to-work structure is set up with some additional features: version 
    control, remote repository creation, CI/CD configuration (check package 
    integrity under several OS, test code with 'testthat', and build and deploy 
    website using 'pkgdown'). This package heavily relies on the R packages 
    'devtools' and 'usethis' and follows recommendations made by Wickham H. 
    (2015) <ISBN:9781491910597> and Marwick B. et al. (2018) 
    <doi:10.7287/peerj.preprints.3192v2>.
URL: https://github.com/FRBCesab/rcompendium,
        https://frbcesab.github.io/rcompendium/
BugReports: https://github.com/FRBCesab/rcompendium/issues
License: GPL (>= 2)
Encoding: UTF-8
Depends: R (>= 2.10)
Imports: cffr, cli, codemetar, devtools, gert, gh, gtools, renv,
        rmarkdown, rstudioapi, stringr, usethis, utils, xfun
RoxygenNote: 7.3.2
VignetteBuilder: knitr
Suggests: fs, knitr, testthat (>= 3.0.0), withr
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2025-09-02 11:48:36 UTC; nicolas
Author: Nicolas Casajus [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0002-5537-5294>)
Maintainer: Nicolas Casajus <nicolas.casajus@fondationbiodiversite.fr>
Repository: CRAN
Date/Publication: 2025-09-02 12:10:02 UTC
Built: R 4.6.0; ; 2026-04-30 01:42:41 UTC; unix
