# Generated by roxygen2: do not edit by hand

export(add_citation)
export(add_code_of_conduct)
export(add_codecov_badge)
export(add_compendium)
export(add_contributing)
export(add_cran_badge)
export(add_dependencies)
export(add_dependencies_badge)
export(add_description)
export(add_dockerfile)
export(add_github_actions_check)
export(add_github_actions_check_badge)
export(add_github_actions_citation)
export(add_github_actions_codecov)
export(add_github_actions_codecov_badge)
export(add_github_actions_codemeta)
export(add_github_actions_document)
export(add_github_actions_pkgdown)
export(add_github_actions_pkgdown_badge)
export(add_github_actions_render)
export(add_license)
export(add_license_badge)
export(add_lifecycle_badge)
export(add_makefile)
export(add_package_doc)
export(add_r_depend)
export(add_readme_rmd)
export(add_renv)
export(add_repostatus_badge)
export(add_testthat)
export(add_to_buildignore)
export(add_to_gitignore)
export(add_vignette)
export(get_all_dependencies)
export(get_all_functions)
export(get_licenses)
export(get_minimal_r_version)
export(new_compendium)
export(new_package)
export(refresh)
export(set_credentials)
importFrom(usethis,ui_code)
importFrom(usethis,ui_done)
importFrom(usethis,ui_field)
importFrom(usethis,ui_info)
importFrom(usethis,ui_line)
importFrom(usethis,ui_oops)
importFrom(usethis,ui_todo)
importFrom(usethis,ui_value)
