---
output: github_document
---

<!-- README.md is generated from README.Rmd. Please edit that file -->


```{r, include = FALSE}
knitr::opts_chunk$set(collapse  = TRUE,
                      comment   = "#>",
                      fig.path  = "figures/readme/",
                      out.width = "100%")
```



{{project_name}} <img src="figures/readme/compendium-sticker.png" align="right" style="float:right; height:120px;"/>
=========================================================

<!-- badges: start -->
<!-- badges: end -->



<p align="left">
  • <a href="#overview">Overview</a><br>
  • <a href="#data-sources">Data sources</a><br>
  • <a href="#workflow">Workflow</a><br>
  • <a href="#content">Content</a><br>
  • <a href="#installation">Installation</a><br>
  • <a href="#usage">Usage</a><br>
  • <a href="#citation">Citation</a><br>
  • <a href="#contributing">Contributing</a><br>
  • <a href="#acknowledgments">Acknowledgments</a><br>
  • <a href="#references">References</a>
</p>



## Overview

This project is dedicated to... **{{ DESCRIBE YOUR PROJECT }}**



## Data sources

This project uses the following databases:

**{{ DESCRIBE THE DATA SOURCES }}**

<!--
| Database        | Usage                                                | Reference                 | Link      |
| :-------------- | :--------------------------------------------------- | :------------------------ | :-------: |
| Database name   | Explain the purpose of this database in the analysis | Database reference        | [link](#) |
-->


## Workflow

The analysis pipeline follows these steps:

**{{ DESCRIBE THE PIPELINE }}**


## Content

This repository is structured as follow:

- [`DESCRIPTION`](https://github.com/{{github}}/{{project_name}}/tree/{{branch}}/DESCRIPTION):
contains project metadata (authors, date, dependencies, etc.)

- [`make.R`](https://github.com/{{github}}/{{project_name}}/tree/{{branch}}/make.R):
main R script to run the entire project

- [`R/`](https://github.com/{{github}}/{{project_name}}/tree/{{branch}}/R):
contains R functions developed especially for this project

**{{ LIST ADDITIONAL FILES/FOLDER }}**



## Installation

To install this compendium:

- [Fork](https://docs.github.com/en/get-started/quickstart/contributing-to-projects) 
this repository using the GitHub interface.
- [Clone](https://docs.github.com/en/repositories/creating-and-managing-repositories/cloning-a-repository) 
your fork using `git clone fork-url` (replace `fork-url` by the URL of your fork). 
Alternatively, open [RStudio IDE](https://posit.co/products/open-source/rstudio/) 
and create a New Project from Version Control.



## Usage

Launch the [`make.R`](https://github.com/{{github}}/{{project_name}}/tree/{{branch}}/make.R)
file with:

```{r eval=FALSE}
source("make.R")
```

**Notes**

- All required packages listed in the `DESCRIPTION` file will be installed (if necessary)
- All required packages and R functions will be loaded
- Some analyses listed in the `make.R` might take time



## Citation

Please use the following citation: 

> **{{ ADD A CITATION }}**



## Contributing

All types of contributions are encouraged and valued. For more information, 
check out our [Contributor Guidelines](https://github.com/{{github}}/{{project_name}}/blob/main/CONTRIBUTING.md).

Please note that this project is released with a 
[Contributor Code of Conduct](https://contributor-covenant.org/version/2/1/CODE_OF_CONDUCT.html). 
By contributing to this project, you agree to abide by its terms.



## Acknowledgments

**{{ OPTIONAL SECTION }}**



## References

**{{ OPTIONAL SECTION }}**
