---
name: Bug report
about: Standard bug report template
title: ''
labels: 'bug'
---

**Bug description**

A clear and concise description of what the bug is.


**Reproducible example**

It is easier for developers to help if they can reproduce the problem.   
Could you please provide a minimal reproducible example?


**Additional context**

Add any other context about the problem here.


<details>
```r
# Output of sessionInfo()
```
</details>
